@@ -1,6 +1,6 @@
 """Package 'playlist2podcast' level definitions."""
-from typing_extensions import Final
+from typing import Final
 
-__version__: Final[str] = "0.6.1"
+__version__: Final[str] = "0.6.3"
 __display_name__: Final[str] = "Playlist2Podcast"
 __package_name__: Final[str] = __display_name__.lower()
