@@ -26,12 +26,12 @@ import re
 from dataclasses import asdict
 from dataclasses import dataclass
 from typing import Any
-from typing import cast
 from typing import Dict
 from typing import List
 from typing import Optional
 from typing import TypeVar
 from typing import Union
+from typing import cast
 
 import arrow
 import requests
@@ -89,6 +89,7 @@ class Configuration:
     youtube_cookie_file: Optional[str]
 
     def __init__(self: CFG, config_file_name: str) -> None:
+        """Initalise Configuration for testing."""
         if os.path.exists(config_file_name):
             with open(file=config_file_name, encoding="UTF-8") as config_file:
                 config = json.load(config_file)
@@ -159,7 +160,8 @@ class Configuration:
 
     def __collect_playlists_info(self: CFG) -> None:
         """Prompts user to enter playlist urls and any associated
-        include/exclude filters."""
+        include/exclude filters.
+        """
         self.play_lists = []
         while True:
             rprint(
@@ -212,7 +214,7 @@ class Configuration:
 
 
 def main() -> None:
-    """Main / Overall Logic of YouTube Playlist to podcast feed conversion.
+    """Convert videos in playlist to podcast feed conversion.
 
     :param: None
     :return: None
@@ -334,7 +336,7 @@ def is_video_included(
     include_filters: List[str],
     exclude_filters: List[str],
 ) -> bool:
-    """Checks video title against include and exclude filters to determine if
+    """Check video title against include and exclude filters to determine if
     video should be considered for adding to podcast or not.
 
     :param video_title: Title of video to check filters against.
@@ -401,7 +403,7 @@ def add_episodes(
     feed: FeedGenerator,
     play_list_info: List[Dict[str, str]],
 ) -> None:
-    """Iterates through play list info and decides which videos to process and
+    """Iterate through play list info and decides which videos to process and
     add to feed and then does so.
 
     :param config: Contains program configuration
@@ -494,7 +496,8 @@ def add_episodes(
 
 def check_updates() -> None:
     """Check if there is a newer version of MastodonAmnesia available on
-    PyPI."""
+    PyPI.
+    """
     is_outdated = False
     try:
         is_outdated, pypi_version = check_outdated(
@@ -525,7 +528,7 @@ def check_updates() -> None:
 
 
 def get_thumbnail(config: Configuration, video_id: str, video: Dict[str, Any]) -> str:
-    """Gets the highest quality thumbnail out of the video dict, converts it to
+    """Get the highest quality thumbnail out of the video dict, converts it to
     JPG and returns the filename of the converted file.
 
     :param config: Configuration class instance
